var module_adapter_8c =
[
    [ "factory_data", "structfactory__data.html", "structfactory__data" ],
    [ "node_data", "structnode__data.html", "structnode__data" ],
    [ "FACTORY_USAGE", "module-adapter_8c.html#a94a91dd105b8ff141516e04283841ca7", null ],
    [ "NAME", "module-adapter_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "PW_LOG_TOPIC_DEFAULT", "module-adapter_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
    [ "pipewire__module_init", "module-adapter_8c.html#a8a1bb60befc3b89c8c1f5417f777083f", null ],
    [ "PW_LOG_TOPIC", "module-adapter_8c.html#a25d870f60f991a83eae379650774a19c", null ]
];